"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_1 = require("vscode-languageserver");
class TreeSitterDiagnostics {
    constructor(connection, elmWorkspaceFolder, forest) {
        this.connection = connection;
        this.elmWorkspaceFolder = elmWorkspaceFolder;
        this.forest = forest;
    }
    createDiagnostics(filePath) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.checkForErrors(this.connection, this.elmWorkspaceFolder.fsPath, filePath.fsPath);
        });
    }
    checkForErrors(connection, rootPath, filename) {
        return __awaiter(this, void 0, void 0, function* () {
            const diagnostics = new Map();
            this.forest.treeIndex.forEach(a => {
                const diag = [];
                const errors = a.tree.rootNode.descendantsOfType("ERROR");
                errors.forEach(b => {
                    if (b) {
                        diag.push(vscode_languageserver_1.Diagnostic.create(vscode_languageserver_1.Range.create(vscode_languageserver_1.Position.create(b.startPosition.row, b.startPosition.column), vscode_languageserver_1.Position.create(b.endPosition.row, b.endPosition.column)), b.text, vscode_languageserver_1.DiagnosticSeverity.Error));
                    }
                });
                const missing = a.tree.rootNode.descendantsOfType("MISSING");
                missing.forEach(b => {
                    if (b) {
                        diag.push(vscode_languageserver_1.Diagnostic.create(vscode_languageserver_1.Range.create(vscode_languageserver_1.Position.create(b.startPosition.row, b.startPosition.column), vscode_languageserver_1.Position.create(b.endPosition.row, b.endPosition.column)), b.text, vscode_languageserver_1.DiagnosticSeverity.Error));
                    }
                });
                diagnostics.set(a.uri, diag);
            });
            return diagnostics;
        });
    }
}
exports.TreeSitterDiagnostics = TreeSitterDiagnostics;
//# sourceMappingURL=treeSitterDiagnostics.js.map