"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_1 = require("vscode-languageserver");
const vscode_uri_1 = require("vscode-uri");
const elmWorkspaceMatcher_1 = require("../util/elmWorkspaceMatcher");
const references_1 = require("../util/references");
const treeUtils_1 = require("../util/treeUtils");
class RenameProvider {
    constructor(connection, elmWorkspaces) {
        this.connection = connection;
        this.handleRenameRequest = (params, elmWorkspace) => __awaiter(this, void 0, void 0, function* () {
            this.connection.console.info(`Renaming was requested`);
            const imports = elmWorkspace.getImports();
            const forest = elmWorkspace.getForest();
            const tree = forest.getTree(params.textDocument.uri);
            if (tree) {
                const nodeAtPosition = treeUtils_1.TreeUtils.getNamedDescendantForPosition(tree.rootNode, params.position);
                const definitionNode = treeUtils_1.TreeUtils.findDefinitionNodeByReferencingNode(nodeAtPosition, params.textDocument.uri, tree, imports);
                if (definitionNode) {
                    const refTree = forest.getByUri(definitionNode.uri);
                    if (refTree && refTree.writeable) {
                        const references = references_1.References.find(definitionNode, forest, imports);
                        if (references) {
                            const map = {};
                            references.forEach(a => {
                                if (!map[a.uri]) {
                                    map[a.uri] = [];
                                }
                                map[a.uri].push(vscode_languageserver_1.TextEdit.replace(vscode_languageserver_1.Range.create(vscode_languageserver_1.Position.create(a.node.startPosition.row, a.node.startPosition.column), vscode_languageserver_1.Position.create(a.node.endPosition.row, a.node.endPosition.column)), params.newName));
                            });
                            if (map) {
                                return {
                                    changes: map,
                                };
                            }
                        }
                    }
                }
            }
            return undefined;
        });
        this.connection.onRenameRequest(new elmWorkspaceMatcher_1.ElmWorkspaceMatcher(elmWorkspaces, (params) => vscode_uri_1.URI.parse(params.textDocument.uri)).handlerForWorkspace(this.handleRenameRequest));
    }
}
exports.RenameProvider = RenameProvider;
//# sourceMappingURL=renameProvider.js.map