"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
const vscode_languageserver_1 = require("vscode-languageserver");
// This is loosely based on https://github.com/Microsoft/vscode-languageserver-node/blob/73180893ca/server/src/main.ts#L124
// With some simplifications and the ability to support multiple listeners
class TextDocumentEvents extends events_1.EventEmitter {
    constructor(events) {
        super();
        this.documents = {};
        events.on("open", (params) => {
            const td = params.textDocument;
            const document = vscode_languageserver_1.TextDocument.create(td.uri, td.languageId, td.version, td.text);
            this.documents[params.textDocument.uri] = document;
            const frozen = Object.freeze({ document });
            this.emit("open", frozen.document);
        });
        events.on("change", (params) => {
            const td = params.textDocument;
            const changes = params.contentChanges;
            const last = changes.length > 0 ? changes[changes.length - 1] : undefined;
            if (last) {
                const document = this.documents[td.uri];
                if (document && TextDocumentEvents.isUpdatableDocument(document)) {
                    if (td.version === null || td.version === void 0) {
                        throw new Error(`Received document change event for ${td.uri} without valid version identifier`);
                    }
                    document.update(last, td.version);
                    const frozen = Object.freeze({ document });
                    this.emit("change", frozen.document);
                }
            }
        });
        events.on("save", (params) => {
            const document = this.documents[params.textDocument.uri];
            if (document) {
                const frozen = Object.freeze({ document });
                this.emit("save", frozen.document);
            }
        });
        events.on("close", (params) => {
            const document = this.documents[params.textDocument.uri];
            if (document) {
                delete this.documents[params.textDocument.uri];
                const frozen = Object.freeze({ document });
                this.emit("close", frozen.document);
            }
        });
    }
    static isUpdatableDocument(value) {
        return typeof value.update === "function";
    }
    /**
     * Returns the document for the given URI. Returns undefined if
     * the document is not managed by this instance.
     *
     * @param uri The text document's URI to retrieve.
     * @return the text document or `undefined`.
     */
    get(uri) {
        return this.documents[uri];
    }
}
exports.TextDocumentEvents = TextDocumentEvents;
//# sourceMappingURL=textDocumentEvents.js.map